/*  Copyright (C) 1998-2002 Jason Lango
 *
 *  This file is part of the Doors for Linux Kernel Module.
 * 
 *  The Doors for Linux Kernel Module is free software; you can
 *  redistribute it and/or modify it under the terms of the GNU
 *  General Public License as published by the Free Software
 *  Foundation; either version 2 of the License, or (at your option)
 *  any later version.
 *
 *  The Doors for Linux Kernel Module is distributed in the hope that
 *  it will be useful, but WITHOUT ANY WARRANTY; without even the
 *  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 *  PURPOSE.  See the GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with the Doors for Linux Kernel Module; if not, write to the
 *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *  Boston, MA  02111-1307  USA
 */

/*
 *  doors_debug.h - Debugging functions and defines.
 *  Jason Lango <jal@rampant.org>
 */

/* Debug flags - set TRUE or FALSE */
#define DEBUG_VM_COPY		1
#define DEBUG_VM_COPY_FAULT	1
#define DEBUG_DOOR_OPENCLOSE	1
#define DEBUG_INARGS_UNMAP	1
#define DEBUG_DOOR_ARGCHECK	1
#define DEBUG_ALLOC		1
#define DEBUG_SERVER_PROCS	1
#define DEBUG_CALL		1
#define DEBUG_RETURN		1
#define DEBUG_TRANSLATE		1
#define DEBUG_REFCOUNTS		1
#define DEBUG_ARGBUF_POISON	1

#ifdef __KERNEL__

#define DOOR_DENTRY_COUNTS(label, dent) do {} while (0)

#	if DOORS_DEBUG_MODULE

#		if DEBUG_REFCOUNTS

#		undef DOOR_DENTRY_COUNTS
#		define DOOR_DENTRY_COUNTS(label, dent) \
			do { \
				door_dentry_counts(label, dent); \
			} while (0)

#		endif /* DEBUG_REFCOUNTS */

#	define dprintk(n,x) \
		do { \
			if (n) printk x ; \
		} while (0)
#	define ASSERT(x) \
		do { \
			if (!(x)) { \
				printk(doors_assert_fmt, doors_banner, \
					__FILE__, __LINE__); \
			} \
		} while (0)

#	else /* !DOORS_DEBUG_MODULE */

#	define dprintk(n,x) do {} while (0)
#	define ASSERT(x) do {} while (0)

#	endif	/* !DOORS_DEBUG_MODULE */

#else /* !__KERNEL__ */

#	if DOORS_DEBUG_LIBRARY

#	include <assert.h>
#	define dprintf(n,x) \
		do { \
			if (n) \
				printf x ; \
		} while (0)
#	define ASSERT assert

#	else /* !DOORS_DEBUG_LIBRARY */

#	define dprintf(n,x) do {} while (0)
#	define ASSERT(x) do {} while (0)

#	endif	/* !DOORS_DEBUG_LIBRARY */

#endif	/* !__KERNEL__ */
