/*  Copyright (C) 1998-2002 Jason Lango
 *
 *  This file is part of the Doors for Linux User Library.
 * 
 *  The Doors for Linux User Library is free software; you can
 *  redistribute it and/or modify it under the terms of the GNU Lesser
 *  General Public License as published by the Free Software
 *  Foundation; either version 2.1 of the License, or (at your option)
 *  any later version.
 *
 *  The Doors for Linux User Library is distributed in the hope that
 *  it will be useful, but WITHOUT ANY WARRANTY; without even the
 *  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 *  PURPOSE.  See the GNU Lesser General Public License for more
 *  details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with the Doors for Linux User Library; if not, write
 *  to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *  Boston, MA  02111-1307  USA
 */

/*
 * libdoor_client.c - Functions for doors clients.
 * Jason Lango <jal@rampant.org>
 */

/*
 * This file contains code common to the client functions.  Code which
 * might be used in a server process should be placed in another file
 * (like door_create.c, for example).  This is important, since
 * single-threaded programs should be able to be linked with client
 * functions e.g. door_call() (without requiring libpthread).
 */

#include "libdoor.h"
#include <stdarg.h>
#include <stdio.h>
#include <sys/fcntl.h>
#include <bits/libc-lock.h>

int __door_dev_fd = -1;

__libc_lock_define_initialized(static, __door_init_lock)

void __door_error(const char *fmt, ...)
{
	va_list pvar;

	va_start(pvar, fmt);

	fprintf(stderr, "libdoor: ERROR: ");
	vfprintf(stderr, fmt, pvar);
	fprintf(stderr, "\n");

	va_end(pvar);
}

void __door_init(void)
{
	__libc_lock_lock(__door_init_lock);

	if (__door_dev_fd >= 0)
		goto out;

	if ((__door_dev_fd = __open(DOORS_DEVICE, O_RDONLY)) < 0) {
		switch (errno) {
		case ENODEV:
			__door_error("Doors kernel module not loaded or "
				"device numbers don't match");
			break;
		default:
			__door_error("unable to open \"%s\": %s",
				DOORS_DEVICE, strerror(errno));
			break;
		}
		goto out;
	}

out:
	__libc_lock_unlock(__door_init_lock);
}
